@@ -28,7 +28,9 @@ from butterfly.util.decorator import async
 from butterfly.handle import ButterflyHandleFactory
 from butterfly.media import ButterflySessionHandler
 
-from telepathy.interfaces import CHANNEL_INTERFACE, CHANNEL_INTERFACE_GROUP
+from telepathy.interfaces import CHANNEL_INTERFACE, CHANNEL_INTERFACE_GROUP,\
+    CHANNEL_TYPE_STREAMED_MEDIA
+from telepathy.constants import MEDIA_STREAM_TYPE_AUDIO, MEDIA_STREAM_TYPE_VIDEO
 
 __all__ = ['ButterflyMediaChannel']
 
@@ -87,6 +89,22 @@ class ButterflyMediaChannel(
         self.GroupFlagsChanged(flags, 0)
         self.__add_initial_participants()
 
+        types = []
+        initial_audio_prop = CHANNEL_TYPE_STREAMED_MEDIA + '.InitialAudio'
+        initial_video_prop = CHANNEL_TYPE_STREAMED_MEDIA + '.InitialVideo'
+        self._add_immutables({
+                'InitialAudio': CHANNEL_TYPE_STREAMED_MEDIA,
+                'InitialVideo': CHANNEL_TYPE_STREAMED_MEDIA,
+                })
+
+        if props.get(initial_audio_prop, False):
+            types.append(MEDIA_STREAM_TYPE_AUDIO)
+        if props.get(initial_video_prop, False):
+            types.append(MEDIA_STREAM_TYPE_VIDEO)
+
+        if types:
+            self.RequestStreams(handle, types)
+
     def Close(self):
         logger.info("Channel closed by client")
         self._call.end()
@@ -207,7 +225,9 @@ class ButterflyMediaChannel(
     #StreamHandler event
     def on_stream_error(self, handler, error, message):
         self.StreamError(handler.id, error, message)
-        self._call.media_session.remove_stream(handler.stream)
+        # TODO: properly remove the stream without ending the whole
+        # call unless it was the last stream of the session.
+        self._call.end()
 
     #StreamHandler event
     def on_stream_state_changed(self, handler, state):
