@@ -32,6 +32,7 @@ from butterfly.handle import ButterflyHandleFactory
 from butterfly.capabilities import ButterflyCapabilities
 from butterfly.contacts import ButterflyContacts
 from butterfly.channel_manager import ButterflyChannelManager
+from butterfly.mail_notification import ButterflyMailNotification
 
 __all__ = ['ButterflyConnection']
 
@@ -45,10 +46,16 @@ class ButterflyConnection(telepathy.server.Connection,
         ButterflyAvatars,
         ButterflyCapabilities,
         ButterflyContacts,
+        ButterflyMailNotification,
         papyon.event.ClientEventInterface,
         papyon.event.InviteEventInterface,
         papyon.event.OfflineMessagesEventInterface):
 
+    _secret_parameters = set([
+            'password',
+            'http-proxy-password',
+            'https-proxy-password'
+            ])
     _mandatory_parameters = {
             'account' : 's',
             'password' : 's'
@@ -100,6 +107,7 @@ class ButterflyConnection(telepathy.server.Connection,
             ButterflyAvatars.__init__(self)
             ButterflyCapabilities.__init__(self)
             ButterflyContacts.__init__(self)
+            ButterflyMailNotification.__init__(self)
             papyon.event.ClientEventInterface.__init__(self, self._msn_client)
             papyon.event.InviteEventInterface.__init__(self, self._msn_client)
             papyon.event.OfflineMessagesEventInterface.__init__(self, self._msn_client)
@@ -245,6 +253,7 @@ class ButterflyConnection(telepathy.server.Connection,
                     telepathy.CHANNEL_TYPE_CONTACT_LIST, handle, False)
                 self._channel_manager.channel_for_props(props, signal=True)
         elif state == papyon.event.ClientState.OPEN:
+            self._populate_capabilities()
             self.StatusChanged(telepathy.CONNECTION_STATUS_CONNECTED,
                     telepathy.CONNECTION_STATUS_REASON_REQUESTED)
             presence = self._initial_presence
@@ -259,6 +268,8 @@ class ButterflyConnection(telepathy.server.Connection,
                 self._presence_changed(ButterflyHandleFactory(self, 'self'),
                         self._client.profile.presence,
                         self._client.profile.personal_message)
+            if self._client.profile.profile['EmailEnabled'] == '1':
+                self.enable_mail_notification_interface()
         elif state == papyon.event.ClientState.CLOSED:
             self.StatusChanged(telepathy.CONNECTION_STATUS_DISCONNECTED,
                     self.__disconnect_reason)
